==> spip_4.0.4.orig.tar.xz: plugins-dist/forum/lang/forum_oc_va.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=oc_va
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'als articles futurs solament (ges d’accion sus la basa de donaas).',
	'bouton_radio_articles_tous' => 'als articles totes sens excepcion',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a totes los articles, fòra aqueles que lor forum es desactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (los utilizaires se devon abonar en donant lor adreiça e-mail avans de poer mandar de contribucions).',
	'bouton_radio_moderation_priori' => 'Moderacion a priòri (las
 contribucions apareisson en public mas que se los administrators
 las an validaas).', # MODIF
	'bouton_radio_modere_abonnement' => 'moderat amb abonament',
	'bouton_radio_modere_posteriori' => 'moderat a posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderat a priòri', # MODIF
	'bouton_radio_publication_immediate' => 'Publicar los messatges sus lo còp
 (las contribucions apareisson tre mandaas, los administrators las pòon
 suprimir puei).',

	// F
	'form_pet_message_commentaire' => 'Un messatge, una remarca?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Poètz pas pus accedir vèrs aqueles forums.',
	'forum_attention_dix_caracteres' => '<b>Atencion!</b> vòstre messatge deu tenir aumens dètz caractèrs.',
	'forum_attention_trois_caracteres' => '<b>Atencion!</b> vòstre títol deu tenir aumens tres caractèrs.',
	'forum_avez_selectionne' => 'Avètz seleccionat:',
	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aicí</a> per contunhar.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Aquest forum es moderat a priòri: vòstra contribucion pareisserà mas qu’après qu’un administrator dau sit l’aia validaa.', # MODIF
	'forum_lien_hyper' => '<b>Liam ipertèxt</b> (opcionau)', # MODIF
	'forum_message_definitif' => 'Messatge definitiu : mandar au sit',
	'forum_message_trop_long' => 'Vòstre messatge es tròp lòng. La lonjor maximala es de 20 000 caractèrs.', # MODIF
	'forum_ne_repondez_pas' => 'Respondatz pas a aquel e-mail mas per lo forum a l’adreiça seguenta: ', # MODIF
	'forum_page_url' => '(se vòstre messatge se referís a un article publicat per lo web, o a una pagina que baile mai d’informacions, volhatz marcar çai sos lo títol de la pagina e son adreiça URL.)',
	'forum_poste_par' => 'Messatge poste@parauteur@ que fai seguia a vòstre article.', # MODIF
	'forum_qui_etes_vous' => '<b>Qui siatz?</b> (opcionau)', # MODIF
	'forum_texte' => 'Tèxt de vòstre messatge:', # MODIF
	'forum_titre' => 'Títol:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Validar aquela chausia',
	'forum_voir_avant' => 'Veire lo messatge avans de lo mandar', # MODIF
	'forum_votre_email' => 'Vòstra adreiça e-mail:', # MODIF
	'forum_votre_nom' => 'Vòstre nom (o pseudonim):', # MODIF
	'forum_vous_enregistrer' => 'Per participar a
  aqueu forum, d’en primier vos chau registrar. Mercé
  de marcar çai sos l’identificant personau qu’avètz recebut.
 Se siatz pas registrat/aa, avètz de',
	'forum_vous_inscrire' => 'vos inscriure',

	// I
	'icone_poster_message' => 'Postar un messatge',
	'icone_suivi_forum' => 'Seguit dau forum public: @nb_forums@ contribucion(s)',
	'icone_suivi_forums' => 'Seguir/gerir los forums',
	'icone_supprimer_message' => 'Suprimir aqueu messatge',
	'icone_valider_message' => 'Validar aqueu messatge',
	'info_activer_forum_public' => '<i>Per activar los forums publics, volhatz chausir lor mòde de moderacion predefinit:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar aquela chausia de moderacion:',
	'info_desactiver_forum_public' => 'Desactivar l’utilizacion dels forums publics. Los forums publics poiràn èsser autorizats au cas per cas sobre los articles; seràn proïbits sobre las rubricas, brèvas, etc.',
	'info_envoi_forum' => 'Mandaís dels forums als autors dels articles',
	'info_fonctionnement_forum' => 'Foncionament dau forum:',
	'info_gauche_suivi_forum_2' => 'La pagina de <i>seguit dels forums</i> es un esplech de gestion dau vòstre sit (mas es pas un espaci per discutir o per redigir). Aficha totas las contribucions dau forum public d’aquel article e vos permet de gerir aquelas contribucions.', # MODIF
	'info_liens_syndiques_3' => 'forums',
	'info_liens_syndiques_4' => 'son',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'es',
	'info_liens_syndiques_7' => 'en espèra de validacion',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mòde de foncionament predefinit dels forums publics',
	'info_option_email' => 'Quand un vesitaire dau sit manda un messatge nòu au forum
 associat a un article, se’n pòt avisar los autors
 de l’article per e-mail. Desiratz d’utilizar aquela opcion?', # MODIF
	'info_pas_de_forum' => 'Ges de forum',
	'item_activer_forum_administrateur' => 'Activar lo forum dels administrators',
	'item_desactiver_forum_administrateur' => 'Desactivar lo forum dels administrators',

	// L
	'lien_reponse_article' => 'Respònsa a l’article',
	'lien_reponse_breve_2' => 'Respònsa a la brèva',
	'lien_reponse_rubrique' => 'Respònsa a la rubrica',
	'lien_reponse_site_reference' => 'Respònsa au sit referenciat:', # MODIF

	// O
	'onglet_messages_internes' => 'Messatges intèrnes',
	'onglet_messages_publics' => 'Messatges publics',
	'onglet_messages_vide' => 'Messatges sensa tèxt',

	// R
	'repondre_message' => 'Respòndre a aqueu messatge',

	// T
	'titre_cadre_forum_administrateur' => 'Forum privat dels administrators',
	'titre_cadre_forum_interne' => 'Forum intèrne',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Seguit dels forums',
	'titre_page_forum_suivi' => 'Seguit dels forums'
);

==> spip_4.2.14+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_oc_va.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=oc_va
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'als articles futurs solament (ges d’accion sus la basa de donaas).',
	'bouton_radio_articles_tous' => 'als articles totes sens excepcion',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a totes los articles, fòra aqueles que lor forum es desactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (los utilizaires se devon abonar en donant lor adreiça e-mail avans de poer mandar de contribucions).',
	'bouton_radio_moderation_priori' => 'Moderacion a priòri (las
 contribucions apareisson en public mas que se los administrators
 las an validaas).', # MODIF
	'bouton_radio_modere_abonnement' => 'moderat amb abonament',
	'bouton_radio_modere_posteriori' => 'moderat a posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderat a priòri', # MODIF
	'bouton_radio_publication_immediate' => 'Publicar los messatges sus lo còp
 (las contribucions apareisson tre mandaas, los administrators las pòon
 suprimir puei).',

	// F
	'form_pet_message_commentaire' => 'Un messatge, una remarca?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Poètz pas pus accedir vèrs aqueles forums.',
	'forum_attention_dix_caracteres' => '<b>Atencion!</b> vòstre messatge deu tenir aumens dètz caractèrs.',
	'forum_attention_trois_caracteres' => '<b>Atencion!</b> vòstre títol deu tenir aumens tres caractèrs.',
	'forum_avez_selectionne' => 'Avètz seleccionat:',
	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aicí</a> per contunhar.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Aquest forum es moderat a priòri: vòstra contribucion pareisserà mas qu’après qu’un administrator dau sit l’aia validaa.', # MODIF
	'forum_lien_hyper' => '<b>Liam ipertèxt</b> (opcionau)', # MODIF
	'forum_message_definitif' => 'Messatge definitiu : mandar au sit',
	'forum_message_trop_long' => 'Vòstre messatge es tròp lòng. La lonjor maximala es de 20 000 caractèrs.', # MODIF
	'forum_ne_repondez_pas' => 'Respondatz pas a aquel e-mail mas per lo forum a l’adreiça seguenta: ', # MODIF
	'forum_page_url' => '(se vòstre messatge se referís a un article publicat per lo web, o a una pagina que baile mai d’informacions, volhatz marcar çai sos lo títol de la pagina e son adreiça URL.)',
	'forum_poste_par' => 'Messatge poste@parauteur@ que fai seguia a vòstre article.', # MODIF
	'forum_qui_etes_vous' => '<b>Qui siatz?</b> (opcionau)', # MODIF
	'forum_texte' => 'Tèxt de vòstre messatge:', # MODIF
	'forum_titre' => 'Títol:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Validar aquela chausia',
	'forum_voir_avant' => 'Veire lo messatge avans de lo mandar', # MODIF
	'forum_votre_email' => 'Vòstra adreiça e-mail:', # MODIF
	'forum_votre_nom' => 'Vòstre nom (o pseudonim):', # MODIF
	'forum_vous_enregistrer' => 'Per participar a
  aqueu forum, d’en primier vos chau registrar. Mercé
  de marcar çai sos l’identificant personau qu’avètz recebut.
 Se siatz pas registrat/aa, avètz de',
	'forum_vous_inscrire' => 'vos inscriure',

	// I
	'icone_poster_message' => 'Postar un messatge',
	'icone_suivi_forum' => 'Seguit dau forum public: @nb_forums@ contribucion(s)',
	'icone_suivi_forums' => 'Seguir/gerir los forums',
	'icone_supprimer_message' => 'Suprimir aqueu messatge',
	'icone_valider_message' => 'Validar aqueu messatge',
	'info_activer_forum_public' => '<i>Per activar los forums publics, volhatz chausir lor mòde de moderacion predefinit:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar aquela chausia de moderacion:',
	'info_desactiver_forum_public' => 'Desactivar l’utilizacion dels forums publics. Los forums publics poiràn èsser autorizats au cas per cas sobre los articles; seràn proïbits sobre las rubricas, brèvas, etc.',
	'info_envoi_forum' => 'Mandaís dels forums als autors dels articles',
	'info_fonctionnement_forum' => 'Foncionament dau forum:',
	'info_gauche_suivi_forum_2' => 'La pagina de <i>seguit dels forums</i> es un esplech de gestion dau vòstre sit (mas es pas un espaci per discutir o per redigir). Aficha totas las contribucions dau forum public d’aquel article e vos permet de gerir aquelas contribucions.', # MODIF
	'info_liens_syndiques_3' => 'forums',
	'info_liens_syndiques_4' => 'son',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'es',
	'info_liens_syndiques_7' => 'en espèra de validacion',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mòde de foncionament predefinit dels forums publics',
	'info_option_email' => 'Quand un vesitaire dau sit manda un messatge nòu au forum
 associat a un article, se’n pòt avisar los autors
 de l’article per e-mail. Desiratz d’utilizar aquela opcion?', # MODIF
	'info_pas_de_forum' => 'Ges de forum',
	'item_activer_forum_administrateur' => 'Activar lo forum dels administrators',
	'item_desactiver_forum_administrateur' => 'Desactivar lo forum dels administrators',

	// L
	'lien_reponse_article' => 'Respònsa a l’article',
	'lien_reponse_breve_2' => 'Respònsa a la brèva',
	'lien_reponse_rubrique' => 'Respònsa a la rubrica',
	'lien_reponse_site_reference' => 'Respònsa au sit referenciat:', # MODIF

	// O
	'onglet_messages_internes' => 'Messatges intèrnes',
	'onglet_messages_publics' => 'Messatges publics',
	'onglet_messages_vide' => 'Messatges sensa tèxt',

	// R
	'repondre_message' => 'Respòndre a aqueu messatge',

	// T
	'titre_cadre_forum_administrateur' => 'Forum privat dels administrators',
	'titre_cadre_forum_interne' => 'Forum intèrne',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Seguit dels forums',
	'titre_page_forum_suivi' => 'Seguit dels forums',
];
